WORC.processing package — WORC 2.1.1 documentation

# WORC.processing package

## Submodules

## WORC.processing.ExtractNLargestBlobsn module

`WORC.processing.ExtractNLargestBlobsn.` `ExtractNLargestBlobsn`(binaryImage, numberToExtract=1)

  Extract N largest blobs from binary image.

  Arguments:
    binaryImage: boolean numpy array one or several contours. numberToExtract: number of blobs to extract (integer).
  Returns:
    binaryImage: boolean numpy are containing only the N
      extracted blobs.

## WORC.processing.RTStructReader module

@author: Zhenwei.Shi, Maastro

usage:

> paste this file in same directory as your main script file and use the following lines

> import DCM_ImgRT_Reader_ZW

> path1=r’c:ABCFolderContainingDicomOfimageCTscan’ path2=r’c:ABCFolderContainingDicomOfRTstruct’ DCM_ImgRT_Reader_ZW.Img_Bimask(image_path=path1,rtstruct_path=path2,ROI_name)

`WORC.processing.RTStructReader.` `ROI_ref`(rtstruct_path, ROI_name)

`WORC.processing.RTStructReader.` `RTStructReader`(RTStructFile, ROI_name, image_folder)
  Input:

    image_path is directory containing dicom files rtstruct_path is directory containing RTstruct files

    > ROI_name is the ROI stored in RTstructure

  Output:
    mask file written in current directory image volume file written in current directory

`WORC.processing.RTStructReader.` `get_dicoms`(input_dir, logfile=None)

`WORC.processing.RTStructReader.` `get_pixels`(scan)

`WORC.processing.RTStructReader.` `load_dicom`(dicom_folder)

`WORC.processing.RTStructReader.` `match_ROIid`(rtstruct_path, ROI_number)

`WORC.processing.RTStructReader.` `poly2mask`(vertex_row_coords, vertex_col_coords, shape)

## WORC.processing.classes module

class `WORC.processing.classes.` `switch`(value)

  Bases: `object`

  Object to mimic the MATLAB switch - case statement.

  `match`(*args)

    Indicate whether or not to enter a case suite

## Module contents